@@ -65,7 +65,7 @@
     return core.opAsync("op_dns_resolve", { query, recordType, options });
   }
 
-  const DEFAULT_CHUNK_SIZE = 16_640;
+  const DEFAULT_CHUNK_SIZE = 64 * 1024;
 
   function tryClose(rid) {
     try {
